/*
* Copyright (c) 2005, Bear Bibeault
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*  - The name of Bear Bibeault may not be used to endorse or promote products
*    derived from this software without specific prior written permission.
*
* This software is provided by the copyright holders and contributors "as is"
* and any express or implied warranties, including, but not limited to, the
* implied warranties of merchantability and fitness for a particular purpose
* are disclaimed. In no event shall the copyright owner or contributors be
* liable for any direct, indirect, incidental, special, exemplary, or
* consequential damages (including, but not limited to, procurement of
* substitute goods or services; loss of use, data, or profits; or business
* interruption) however caused and on any theory of liability, whether in
* contract, strict liability, or tort (including negligence or otherwise)
* arising in any way out of the use of this software, even if advised of the
* possibility of such damage.
*/
package org.bibeault.jrjournal.ccc;

import java.util.Collection;
import java.util.Map;
import java.util.Set;

/**
 * Implementation of <code>java.util.Map</code> that enables class constant access from
 * EL expressions. This class only implements the get() method of the Map
 * interface so that an instance of this object, when established as a scoped
 * variable, can be used to access class constants using the EL notation for
 * accessing Map entries.
 *
 * Depending upon your point of view, this could be viewed as incredibly clever,
 * or the worst hack you've seen in your life. I think it's both!
 *
 * @author <a href="mailto:bear@javaranch.com">Bear Bibeault</a>
 */
public class ClassConstantMapper implements Map {

    public int size() { throw new UnsupportedOperationException(); }
    public void clear() { throw new UnsupportedOperationException(); }
    public boolean isEmpty() { throw new UnsupportedOperationException(); }
    public boolean containsKey( Object key ) { throw new UnsupportedOperationException(); }
    public boolean containsValue( Object value ) { throw new UnsupportedOperationException(); }
    public Collection values() { throw new UnsupportedOperationException(); }
    public void putAll( Map t ) {  throw new UnsupportedOperationException(); }
    public Set entrySet() { throw new UnsupportedOperationException(); }
    public Set keySet() { throw new UnsupportedOperationException(); }
    public Object remove( Object key ) { throw new UnsupportedOperationException(); }
    public Object put( Object key, Object value ) { throw new UnsupportedOperationException(); }

    public Object get( Object key ) {
        try {
            return ClassConstantInspector.getValue( key.toString() );
        }
        catch (Exception e) {
            throw new IllegalArgumentException( "Error looking up value of constant " + key.toString() + ": " + e.getMessage() );
        }
    }

}
