/*
* Copyright (c) 2005, Bear Bibeault
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*  - The name of Bear Bibeault may not be used to endorse or promote products
*    derived from this software without specific prior written permission.
*
* This software is provided by the copyright holders and contributors "as is"
* and any express or implied warranties, including, but not limited to, the
* implied warranties of merchantability and fitness for a particular purpose
* are disclaimed. In no event shall the copyright owner or contributors be
* liable for any direct, indirect, incidental, special, exemplary, or
* consequential damages (including, but not limited to, procurement of
* substitute goods or services; loss of use, data, or profits; or business
* interruption) however caused and on any theory of liability, whether in
* contract, strict liability, or tort (including negligence or otherwise)
* arising in any way out of the use of this software, even if advised of the
* possibility of such damage.
*/
package org.bibeault.jrjournal.ccc;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * A utility class that parses the simple field name and its declaring class
 * from the fully qualified name (path) of the field.
 *
 * @author <a href="mailto:bear@javaranch.com">Bear Bibeault</a>
 */
public class FieldPathParser {

    private static final String REGEX_FIELD_PATH = "((\\w+\\.)+)(\\w+)";
    private static final int GROUP_INDEX_CLASS = 1;
    private static final int GROUP_INDEX_FIELD = 3;

    private String className;
    private String fieldName;

    /**
     * Constructor for the parser. The fully qualified field name is parsed into
     * its simple name and its declaring class name.
     *
     * @param path the fully qualified name (path) of the field
     */
    public FieldPathParser( String path ) {
        Matcher matcher = Pattern.compile( REGEX_FIELD_PATH ).matcher( path );
        matcher.find();
        this.className = matcher.group( GROUP_INDEX_CLASS );
        this.className = className.substring( 0, className.length() - 1 );
        this.fieldName = matcher.group( GROUP_INDEX_FIELD );
    }

    public String getDeclaringClassName() { return this.className; }
    public String getFieldName() { return this.fieldName; }

}
